#ifndef _CFG_H
#define _CFG_H

#include <gtk/gtk.h>
#include <stdio.h>

struct tConfig
{
	char * server_hostname;
	unsigned short server_port;
	gboolean server_connect_on_startup;
	gboolean server_try_reconnecting;
	char * user_name;
	char * user_passwd;
	gboolean user_save_passwd;
	gboolean misc_event_window;
//	gboolean misc_mini_throughput;
	int wnd_linemaster_x;
	int wnd_linemaster_y;
	int wnd_linemaster_w;
	int wnd_linemaster_h;
	int wnd_messages_w;
	int wnd_messages_h;
	int wnd_activity_x;
	int wnd_activity_y;
	gboolean wnd_activity_show;
	int default_line;
	gboolean start_minimized;
	char * online_script;
	char * offline_script;
	gboolean mysql_enable;
	char * mysql_host;
	char * mysql_user;
	char * mysql_pass;
	char * mysql_db;
	gboolean addrbook_ask;
	gboolean detach;
};

extern struct tConfig *config;

extern char * cfgfile; /* config filename given as argument */

int config_save();
int config_init();

FILE * config_ahup_open_read();
FILE * config_ahup_open_write();

#endif
